@@ -527,6 +527,15 @@ class LookupBaseTests(LookupBaseFallbackTests):
         from zope.interface.adapter import LookupBase
         return LookupBase
 
+    def test_optimizations(self):
+        from zope.interface.adapter import LookupBaseFallback
+        try:
+            import zope.interface._zope_interface_coptimizations
+        except ImportError:
+            self.assertIs(self._getTargetClass(), LookupBaseFallback)
+        else:
+            self.assertIsNot(self._getTargetClass(), LookupBaseFallback)
+
 
 class VerifyingBaseFallbackTests(unittest.TestCase):
 
@@ -689,6 +698,15 @@ class VerifyingBaseTests(VerifyingBaseFallbackTests):
         from zope.interface.adapter import VerifyingBase
         return VerifyingBase
 
+    def test_optimizations(self):
+        from zope.interface.adapter import VerifyingBaseFallback
+        try:
+            import zope.interface._zope_interface_coptimizations
+        except ImportError:
+            self.assertIs(self._getTargetClass(), VerifyingBaseFallback)
+        else:
+            self.assertIsNot(self._getTargetClass(), VerifyingBaseFallback)
+
 
 class AdapterLookupBaseTests(unittest.TestCase):
 
@@ -1350,8 +1368,8 @@ class Test_utils(unittest.TestCase):
 
     def test__normalize_name_unicode(self):
         from zope.interface.adapter import _normalize_name
-        from zope.interface._compat import _u
-        USTR = _u('ustr')
+        
+        USTR = u'ustr'
         self.assertEqual(_normalize_name(USTR), USTR)
 
     def test__normalize_name_other(self):
